summaryrefslogtreecommitdiffhomepage
path: root/Hash.hs
diff options
context:
space:
mode:
Diffstat (limited to 'Hash.hs')
-rw-r--r--Hash.hs8
1 files changed, 4 insertions, 4 deletions
diff --git a/Hash.hs b/Hash.hs
index 3bfb5a2..3cc8d94 100644
--- a/Hash.hs
+++ b/Hash.hs
@@ -12,8 +12,8 @@ class Hashable a where
hash :: a -> Hash
instance Hashable B.ByteString where
- -- Encodes the SHA256 using base16 format
- hash = Hash SHA256 . Val . C8.pack . show . sha256
+ -- Encodes the SHA512 using base16 format
+ hash = Hash SHA512 . Val . C8.pack . show . sha512
instance Hashable Val where
hash (Val v) = hash v
@@ -21,8 +21,8 @@ instance Hashable Val where
instance Hashable Hash where
hash = id
-sha256 :: B.ByteString -> H.Digest H.SHA256
-sha256 = H.hash
+sha512 :: B.ByteString -> H.Digest H.SHA512
+sha512 = H.hash
-- | A value tagged with a ByteString describing the type of value.
-- This is hashed by hashing the concacenation of the hash of the